# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:38:15 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
expressions = {}

# END OF FILE



"""
Some simple tests to check that the framework is properly wrapped.
"""
import AppleScriptKit
import objc
from PyObjCTools.TestSupport import TestCase


class TestAppleScriptKit(TestCase):
    def testClasses(self):
        self.assertHasAttr(AppleScriptKit, "ASKPluginObject")
        self.assertIsInstance(AppleScriptKit.ASKPluginObject, objc.objc_class)
